@@ -9,7 +9,7 @@ https://raw.github.com/bengillies/chrjs.store/master/dist/chrjs-store-latest.js
  *
  * Dependencies: chrjs library, jQuery, TiddlySpace
  *
- * Version: 0.5.0
+ * Version: 0.5.2
  *
  * created by Ben Gillies
  * Chrjs-Store is distributed under a BSD License
@@ -503,9 +503,14 @@ Tiddlers = function(store, tiddlers) {
 	return self;
 };
 
-// Check if match is in field
-contains = function(field, match) {
-	return (field && field.indexOf(match) !== -1) ? true : false;
+// Check if match is in field. fuzzy states whether exact match or just found in
+// default is false
+contains = function(field, match, fuzzy) {
+	if ((!fuzzy) && (field && !(field instanceof Array))) {
+		return (field && field === match) ? true : false;
+	} else {
+		return (field && ~field.indexOf(match)) ? true : false;
+	}
 };
 
 Tiddlers.fn = {
@@ -523,17 +528,17 @@ Tiddlers.fn = {
 	},
 	tag: function(match) {
 		return this.map(function(tiddler) {
-			return contains(tiddler.tags, match) ? tiddler : null;
+			return contains(tiddler.tags, match, true) ? tiddler : null;
 		});
 	},
 	text: function(match) {
 		return this.map(function(tiddler) {
-			return contains(tiddler.text, match) ? tiddler : null;
+			return contains(tiddler.text, match, true) ? tiddler : null;
 		});
 	},
 	title: function(match) {
 		return this.map(function(tiddler) {
-			return contains(tiddler.title, match) ? tiddler : null;
+			return contains(tiddler.title, match, false) ? tiddler : null;
 		});
 	},
 	attr: function(name, match) {
@@ -546,7 +551,7 @@ Tiddlers.fn = {
 			if (chkExists) {
 				return (getValue(tiddler)) ? tiddler : null;
 			} else {
-				return contains(getValue(tiddler), match) ? tiddler : null;
+				return contains(getValue(tiddler), match, false) ? tiddler : null;
 			}
 		});
 	},
@@ -560,7 +565,7 @@ Tiddlers.fn = {
 			if (chkExists) {
 				return (getValue(tiddler)) ? null : tiddler;
 			} else {
-				return contains(getValue(tiddler), match) ? null : tiddler;
+				return contains(getValue(tiddler), match, false) ? null : tiddler;
 			}
 		});
 	},
@@ -1053,7 +1058,7 @@ return function(container) {
 
 	// Assume default host of /, and that a (list of) tiddler(s) is returned from / as well
 	// XXX: This can probably be _vastly_ improved for non-TiddlySpace use-cases
-	var determineContainer = function(callback) {
+	var determineContainerFromTiddler = function(callback) {
 		$.ajax({
 			url: '/?limit=1', // get a tiddler from whatever is default
 			dataType: 'json',
@@ -1086,6 +1091,29 @@ return function(container) {
 		});
 	};
 
+	// assume that /status returns a space attribute that can be used tpo figure out
+	// default containers. Fallback to determineContainerFromTiddler if it doesn't
+	var determineContainer = function(callback) {
+		$.ajax({
+			url: '/status', // expect a "space" attribute back from /status
+			dataType: 'json',
+			success: function(data) {
+				var res = data.space;
+				if (res) {
+					callback({
+						pullFrom: new tiddlyweb.Recipe(res.recipe, '/'),
+						pushTo: new tiddlyweb.Bag(res.name + '_public', '/')
+					});
+				} else {
+					determineContainerFromTiddler(callback);
+				}
+			},
+			error: function(xhr, txtStatus, err) {
+				determineContainerFromTiddler(callback);
+			}
+		});
+	};
+
 	// return default containers (callback is optional, but must be present if
 	// defaultContainer hasn't been discovered yet.
 	var getDefaultContainer = function(callback) {
